==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ColumnFragmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FragmentBaseDescriptionMetadata } from "./FragmentBaseDescriptionMetadata";
import { ColumnFragmentDescription } from "./ColumnFragmentDescription";
/**
 * @hidden
 */
export let ColumnFragmentDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnFragmentDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnFragmentDescriptionMetadata.a == null) {
                ColumnFragmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnFragmentDescriptionMetadata.c(ColumnFragmentDescriptionMetadata.a);
            }
            if (a.j(ColumnFragmentDescriptionMetadata.a)) {
                return;
            }
            a.y(ColumnFragmentDescriptionMetadata.a);
        }
        static c(a) {
            FragmentBaseDescriptionMetadata.c(a);
            a.item("RadiusX", "Number:double");
            a.item("RadiusY", "Number:double");
        }
        static d(a) {
            ColumnFragmentDescriptionMetadata.b(a);
            a.aa("ColumnFragment", () => new ColumnFragmentDescription());
            a.z("ColumnFragment", ColumnFragmentDescriptionMetadata.a);
        }
    }
    ColumnFragmentDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnFragmentDescriptionMetadata, 'ColumnFragmentDescriptionMetadata');
    ColumnFragmentDescriptionMetadata.a = null;
    return ColumnFragmentDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ColumnFragmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { FragmentBaseDescriptionMetadata } from "./FragmentBaseDescriptionMetadata";
import { ColumnFragmentDescription } from "./ColumnFragmentDescription";
/**
 * @hidden
 */
export let ColumnFragmentDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnFragmentDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnFragmentDescriptionMetadata.a == null) {
                ColumnFragmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnFragmentDescriptionMetadata.c(ColumnFragmentDescriptionMetadata.a);
            }
            if (a.k(ColumnFragmentDescriptionMetadata.a)) {
                return;
            }
            a.aa(ColumnFragmentDescriptionMetadata.a);
        }
        static c(a) {
            FragmentBaseDescriptionMetadata.c(a);
            a.item("RadiusX", "Number:double");
            a.item("RadiusY", "Number:double");
        }
        static d(a) {
            ColumnFragmentDescriptionMetadata.b(a);
            a.ac("ColumnFragment", () => new ColumnFragmentDescription());
            a.ab("ColumnFragment", ColumnFragmentDescriptionMetadata.a);
        }
    }
    ColumnFragmentDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnFragmentDescriptionMetadata, 'ColumnFragmentDescriptionMetadata');
    ColumnFragmentDescriptionMetadata.a = null;
    return ColumnFragmentDescriptionMetadata;
})();
